==> kornia-0.6.5.tar.gz: kornia-0.6.5/kornia/feature/__init__.py <==
from .affine_shape import LAFAffineShapeEstimator, LAFAffNetShapeEstimator, PatchAffineShapeEstimator
from .defmo import DeFMO
from .hardnet import HardNet, HardNet8
from .hynet import TLU, FilterResponseNorm2d, HyNet
from .integrated import (
    GFTTAffNetHardNet,
    KeyNetAffNetHardNet,
    KeyNetHardNet,
    LAFDescriptor,
    LocalFeature,
    LocalFeatureMatcher,
    SIFTFeature,
    get_laf_descriptors,
)
from .keynet import KeyNet, KeyNetDetector
from .laf import (
    denormalize_laf,
    ellipse_to_laf,
    extract_patches_from_pyramid,
    extract_patches_simple,
    get_laf_center,
    get_laf_orientation,
    get_laf_scale,
    laf_from_center_scale_ori,
    laf_from_three_points,
    laf_is_inside_image,
    laf_to_boundary_points,
    laf_to_three_points,
    make_upright,
    normalize_laf,
    perspective_transform_lafs,
    raise_error_if_laf_is_not_valid,
    scale_laf,
    set_laf_orientation,
)
from .loftr import LoFTR
from .matching import DescriptorMatcher, match_mnn, match_nn, match_smnn, match_snn
from .mkd import MKDDescriptor
from .orientation import LAFOrienter, OriNet, PatchDominantGradientOrientation
from .responses import (
    BlobDoG,
    BlobHessian,
    CornerGFTT,
    CornerHarris,
    dog_response,
    gftt_response,
    harris_response,
    hessian_response,
)
from .scale_space_detector import PassLAF, ScaleSpaceDetector
from .siftdesc import DenseSIFTDescriptor, SIFTDescriptor
from .sosnet import SOSNet
from .tfeat import TFeat

__all__ = [
    "match_nn",
    "match_mnn",
    "match_snn",
    "match_smnn",
    "DescriptorMatcher",
    "get_laf_descriptors",
    "LAFDescriptor",
    "LocalFeature",
    "SIFTFeature",
    "GFTTAffNetHardNet",
    "LocalFeatureMatcher",
    "SOSNet",
    "KeyNet",
    "harris_response",
    "gftt_response",
    "hessian_response",
    "dog_response",
    "CornerHarris",
    "CornerGFTT",
    "BlobHessian",
    "BlobDoG",
    "extract_patches_from_pyramid",
    "extract_patches_simple",
    "normalize_laf",
    "denormalize_laf",
    "laf_to_boundary_points",
    "ellipse_to_laf",
    "make_upright",
    "get_laf_scale",
    "get_laf_center",
    "get_laf_orientation",
    "set_laf_orientation",
    "get_laf_descriptors",
    "scale_laf",
    "SIFTDescriptor",
    "DenseSIFTDescriptor",
    "MKDDescriptor",
    "HardNet",
    "HardNet8",
    "HyNet",
    "TLU",
    "FilterResponseNorm2d",
    "DeFMO",
    "TFeat",
    "OriNet",
    "LAFAffNetShapeEstimator",
    "PassLAF",
    "ScaleSpaceDetector",
    "LAFAffineShapeEstimator",
    "PatchAffineShapeEstimator",
    "LAFOrienter",
    "PatchDominantGradientOrientation",
    "raise_error_if_laf_is_not_valid",
    "laf_is_inside_image",
    "laf_from_center_scale_ori",
    "laf_to_three_points",
    "laf_from_three_points",
    "match_nn",
    "match_mnn",
    "match_snn",
    "match_smnn",
    "LocalFeatureMatcher",
    "LocalFeature",
    "SIFTFeature",
    "GFTTAffNetHardNet",
    "KeyNet",
    "KeyNetDetector",
    "KeyNetHardNet",
    "KeyNetAffNetHardNet",
    "LAFDescriptor",
    "DescriptorMatcher",
    "LoFTR",
    "perspective_transform_lafs",
]

==> kornia-0.6.9.tar.gz: kornia-0.6.9/kornia/feature/__init__.py <==
from .affine_shape import LAFAffineShapeEstimator, LAFAffNetShapeEstimator, PatchAffineShapeEstimator
from .defmo import DeFMO
from .hardnet import HardNet, HardNet8
from .hynet import TLU, FilterResponseNorm2d, HyNet
from .integrated import (
    GFTTAffNetHardNet,
    KeyNetAffNetHardNet,
    KeyNetHardNet,
    LAFDescriptor,
    LocalFeature,
    LocalFeatureMatcher,
    SIFTFeature,
    get_laf_descriptors,
)
from .keynet import KeyNet, KeyNetDetector
from .laf import (
    KORNIA_CHECK_LAF,
    denormalize_laf,
    ellipse_to_laf,
    extract_patches_from_pyramid,
    extract_patches_simple,
    get_laf_center,
    get_laf_orientation,
    get_laf_scale,
    laf_from_center_scale_ori,
    laf_from_three_points,
    laf_is_inside_image,
    laf_to_boundary_points,
    laf_to_three_points,
    make_upright,
    normalize_laf,
    perspective_transform_lafs,
    scale_laf,
    set_laf_orientation,
)
from .loftr import LoFTR
from .matching import (
    DescriptorMatcher,
    GeometryAwareDescriptorMatcher,
    match_adalam,
    match_fginn,
    match_mnn,
    match_nn,
    match_smnn,
    match_snn,
)
from .mkd import MKDDescriptor
from .orientation import LAFOrienter, OriNet, PatchDominantGradientOrientation
from .responses import (
    BlobDoG,
    BlobHessian,
    CornerGFTT,
    CornerHarris,
    dog_response,
    gftt_response,
    harris_response,
    hessian_response,
)
from .scale_space_detector import PassLAF, ScaleSpaceDetector
from .siftdesc import DenseSIFTDescriptor, SIFTDescriptor
from .sold2 import SOLD2, SOLD2_detector
from .sosnet import SOSNet
from .tfeat import TFeat

__all__ = [
    "match_nn",
    "match_mnn",
    "match_snn",
    "match_smnn",
    "match_fginn",
    "match_adalam",
    "DescriptorMatcher",
    "GeometryAwareDescriptorMatcher",
    "get_laf_descriptors",
    "LAFDescriptor",
    "LocalFeature",
    "SIFTFeature",
    "GFTTAffNetHardNet",
    "LocalFeatureMatcher",
    "SOSNet",
    "KeyNet",
    "harris_response",
    "gftt_response",
    "hessian_response",
    "dog_response",
    "CornerHarris",
    "CornerGFTT",
    "BlobHessian",
    "BlobDoG",
    "extract_patches_from_pyramid",
    "extract_patches_simple",
    "normalize_laf",
    "denormalize_laf",
    "laf_to_boundary_points",
    "ellipse_to_laf",
    "make_upright",
    "get_laf_scale",
    "get_laf_center",
    "get_laf_orientation",
    "set_laf_orientation",
    "get_laf_descriptors",
    "scale_laf",
    "SIFTDescriptor",
    "DenseSIFTDescriptor",
    "MKDDescriptor",
    "HardNet",
    "HardNet8",
    "HyNet",
    "TLU",
    "FilterResponseNorm2d",
    "DeFMO",
    "TFeat",
    "OriNet",
    "LAFAffNetShapeEstimator",
    "PassLAF",
    "ScaleSpaceDetector",
    "LAFAffineShapeEstimator",
    "PatchAffineShapeEstimator",
    "LAFOrienter",
    "PatchDominantGradientOrientation",
    "KORNIA_CHECK_LAF",
    "laf_is_inside_image",
    "laf_from_center_scale_ori",
    "laf_to_three_points",
    "laf_from_three_points",
    "match_nn",
    "match_mnn",
    "match_snn",
    "match_smnn",
    "LocalFeatureMatcher",
    "LocalFeature",
    "SIFTFeature",
    "GFTTAffNetHardNet",
    "KeyNet",
    "KeyNetDetector",
    "KeyNetHardNet",
    "KeyNetAffNetHardNet",
    "LAFDescriptor",
    "DescriptorMatcher",
    "LoFTR",
    "perspective_transform_lafs",
    "SOLD2_detector",
    "SOLD2",
]
